@@ -42,7 +42,7 @@ Q_SIGNALS:
     void settingsChanged();
 
 protected:
-    void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
+    void showEvent(QShowEvent *event) override;
 
 private Q_SLOTS:
     void populateSkinList();
@@ -93,8 +93,8 @@ private:
 
     QString m_selectedSkinId;
 
-    QStandardItemModel *m_skins;
-    SkinListDelegate *m_skinListDelegate;
+    QStandardItemModel *m_skins = nullptr;
+    SkinListDelegate *m_skinListDelegate = nullptr;
 
     QString m_localSkinsDir;
     QString m_knsSkinDir;
