@@ -55,10 +55,6 @@ int main(int argc, char *argv[])
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
-    app.setApplicationName(aboutData.componentName());
-    app.setApplicationDisplayName(aboutData.displayName());
-    app.setOrganizationDomain(aboutData.organizationDomain());
-    app.setApplicationVersion(aboutData.version());
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("yakuake")));
 
     KDBusService service(KDBusService::Unique);
